pub enum ContractAccessError {
DoesntExist,
IsTombstone,
}Expand description
The possible errors that can happen querying the storage of a contract.
Variants
DoesntExist
The given address doesn’t point to a contract.
IsTombstone
The specified contract is a tombstone and thus cannot have any storage.